@@ -87,6 +87,7 @@ class Filter(Device):
     type: FilterType = Field(..., title="Filter Type")
     diameter: float = Field(..., title="Size (mm)", ge=0)
     thickness: float = Field(..., title="Size (mm)", ge=0)
+    filter_wheel_index: int = Field(..., title="Filter wheel index")
     description: Optional[str] = Field(
         None, description="Where/how filter is being used", title="Description"
     )
@@ -115,9 +116,8 @@ class Lightsource(Device):
 
     type: LightsourceType = Field(..., title="Lightsource Type")
     coupling: Coupling = Field(..., title="Coupling")
-    wavelength: float = Field(..., title="Wavelength (nm)", ge=300, le=1000)
-    max_power: float = Field(..., title=" Maximum power (mW)")
-    filter_wheel_index: int = Field(..., title="Filter index")
+    wavelength: float = Field(..., title="Wavelength (nm)", units="nm", ge=300, le=1000)
+    max_power: float = Field(..., title=" Maximum power (mW)", units="mW")
 
 
 class Immersion(Enum):
@@ -157,11 +157,41 @@ class AdditionalImagingDevice(Device):
     type: ImagingDeviceType = Field(..., title="Device type")
 
 
+class StageAxis(Enum):
+    """Direction of motion for motorized stage"""
+    DETECTION_AXIS = "Detection axis"
+    ILLUMINATION_AXIS = "Illumination axis"
+    PERPENDICULAR_AXIS = "Perpendicular axis"
+
+class MotorizedStage(Device):
+    """Description of motorized stage"""
+    axis: StageAxis = Field(..., title="Axis of stage")
+    travel: float = Field(...,title="Travel of device (mm)", units="mm")
+
+class DAQ(Device):
+    """Description of DAQ device"""
+    device_name: str = Field(..., title="PC device name")
+    update_frequency: float = Field(
+        ..., title="DAQ update frequency (Hz)", units="Hz"
+    )
+    daq_ao_names_to_channel: Optional[List[AnalogOutput]] = Field(
+        None, title="DAQ analog outputs", unique_items=True
+    )
+
+class OpticalTable(Device):
+    """Description of Optical Table"""
+    length: Optional[float] = Field(
+        None, title="Length (inches)", units="inches", ge=0
+    )
+    width: Optional[float] = Field(
+        None, title="Width (inches)", units="inches", ge=0
+    )
+
 class Instrument(AindSchema):
     """Description of an instrument, which is a collection of devices"""
 
     version: str = Field(
-        "0.2.0", description="schema version", title="Version", const=True
+        "0.3.0", description="schema version", title="Version", const=True
     )
     instrument_id: Optional[str] = Field(
         None,
@@ -176,12 +206,7 @@ class Instrument(AindSchema):
     )
     humidity_control: Optional[bool] = Field(None, title="Humidity control")
     vibration_control: Optional[bool] = Field(None, title="Vibration control")
-    optical_table_model: Optional[str] = Field(
-        None, title="Optical table model"
-    )
-    optical_table_size: Optional[float] = Field(
-        None, title="Optical table size"
-    )
+    optical_table: List[OpticalTable] = Field(None, title="Optical table")
     objectives: List[Objective] = Field(
         ..., title="Objectives", unique_items=True
     )
@@ -194,9 +219,10 @@ class Instrument(AindSchema):
     fluorescence_filters: Optional[List[Filter]] = Field(
         None, title="Fluorescence filters", unique_items=True
     )
-    motorized_stages: Optional[List[Device]] = Field(
+    motorized_stages: Optional[List[MotorizedStage]] = Field(
         None, title="Motorized stages", unique_items=True
     )
+    daqs: Optional[List[DAQ]] = Field(None, title="DAQ", unique_items=True)
     additional_devices: Optional[List[AdditionalImagingDevice]] = Field(
         None, title="Additional devices", unique_items=True
     )
@@ -210,20 +236,6 @@ class Instrument(AindSchema):
         description="Path to calibration data from most recent calibration",
         title="Calibration data",
     )
-    daq_device_name: Optional[str] = Field(
-        None,
-        description="DAQ device name as it appears to the PC",
-        title="DAQ device name",
-    )
-    daq_model_name: Optional[str] = Field(
-        None, description="DAQ product name", title="DAQ model"
-    )
-    daq_update_frequency: Optional[float] = Field(
-        None, title="DAQ update frequency (Hz)"
-    )
-    daq_ao_names_to_channel: Optional[List[AnalogOutput]] = Field(
-        None, title="DAQ analog outputs", unique_items=True
-    )
     com_ports: Optional[List[Com]] = Field(
         None, title="COM ports", unique_items=True
     )
