@@ -10,6 +10,7 @@ from aind_data_schema.procedures import (
     OphysProbe,
     RetroOrbitalInjection,
     NanojectInjection,
+    InjectionMaterial,
 )
 
 
@@ -36,9 +37,15 @@ class ProceduresTests(unittest.TestCase):
                     end_date=now,
                     experimenter_full_name="tom",
                     protocol_id="134",
-                    injection_virus="abc",
+                    injection_materials=[
+                        InjectionMaterial(
+                            name="abc",
+                            titer="5.46E13",
+                            prep_lot_number="CT323",
+                        )
+                    ],
                     injection_volume=1,
-                    injection_eye="left",
+                    injection_eye="Left",
                     injection_duration=1,
                 ),
                 NanojectInjection(
@@ -46,7 +53,13 @@ class ProceduresTests(unittest.TestCase):
                     end_date=now,
                     experimenter_full_name="betsy",
                     protocol_id="bca",
-                    injection_virus="fds",
+                    injection_materials=[
+                        InjectionMaterial(
+                            name="abc",
+                            titer="5.46E13",
+                            prep_lot_number="CT323",
+                        )
+                    ],
                     injection_duration=1,
                     injection_coordinate_ml=1,
                     injection_coordinate_ap=1,
